@@ -33,7 +33,7 @@ from google.cloud.accessapproval_v1.types import accessapproval
 from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
 from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
 
-from .transports.base import AccessApprovalTransport
+from .transports.base import AccessApprovalTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import AccessApprovalGrpcAsyncIOTransport
 from .client import AccessApprovalClient
 
@@ -81,9 +81,47 @@ class AccessApprovalAsyncClient:
     DEFAULT_ENDPOINT = AccessApprovalClient.DEFAULT_ENDPOINT
     DEFAULT_MTLS_ENDPOINT = AccessApprovalClient.DEFAULT_MTLS_ENDPOINT
 
+    common_billing_account_path = staticmethod(
+        AccessApprovalClient.common_billing_account_path
+    )
+    parse_common_billing_account_path = staticmethod(
+        AccessApprovalClient.parse_common_billing_account_path
+    )
+
+    common_folder_path = staticmethod(AccessApprovalClient.common_folder_path)
+    parse_common_folder_path = staticmethod(
+        AccessApprovalClient.parse_common_folder_path
+    )
+
+    common_organization_path = staticmethod(
+        AccessApprovalClient.common_organization_path
+    )
+    parse_common_organization_path = staticmethod(
+        AccessApprovalClient.parse_common_organization_path
+    )
+
+    common_project_path = staticmethod(AccessApprovalClient.common_project_path)
+    parse_common_project_path = staticmethod(
+        AccessApprovalClient.parse_common_project_path
+    )
+
+    common_location_path = staticmethod(AccessApprovalClient.common_location_path)
+    parse_common_location_path = staticmethod(
+        AccessApprovalClient.parse_common_location_path
+    )
+
     from_service_account_file = AccessApprovalClient.from_service_account_file
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> AccessApprovalTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            AccessApprovalTransport: The transport used by the client instance.
+        """
+        return self._client.transport
+
     get_transport_class = functools.partial(
         type(AccessApprovalClient).get_transport_class, type(AccessApprovalClient)
     )
@@ -94,6 +132,7 @@ class AccessApprovalAsyncClient:
         credentials: credentials.Credentials = None,
         transport: Union[str, AccessApprovalTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
+        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiate the access approval client.
 
@@ -109,16 +148,19 @@ class AccessApprovalAsyncClient:
             client_options (ClientOptions): Custom options for the client. It
                 won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
-                default endpoint provided by the client. GOOGLE_API_USE_MTLS
+                default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                 environment variable can also be used to override the endpoint:
                 "always" (always use the default mTLS endpoint), "never" (always
-                use the default regular endpoint, this is the default value for
-                the environment variable) and "auto" (auto switch to the default
-                mTLS endpoint if client SSL credentials is present). However,
-                the ``api_endpoint`` property takes precedence if provided.
-                (2) The ``client_cert_source`` property is used to provide client
-                SSL credentials for mutual TLS transport. If not provided, the
-                default SSL credentials will be used if present.
+                use the default regular endpoint) and "auto" (auto switch to the
+                default mTLS endpoint if client certificate is present, this is
+                the default value). However, the ``api_endpoint`` property takes
+                precedence if provided.
+                (2) If GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
+                is "true", then the ``client_cert_source`` property can be used
+                to provide client certificate for mutual TLS transport. If
+                not provided, the default SSL client certificate will be used if
+                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
+                set, no client certificate will be used.
 
         Raises:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
@@ -126,7 +168,10 @@ class AccessApprovalAsyncClient:
         """
 
         self._client = AccessApprovalClient(
-            credentials=credentials, transport=transport, client_options=client_options,
+            credentials=credentials,
+            transport=transport,
+            client_options=client_options,
+            client_info=client_info,
         )
 
     async def list_approval_requests(
@@ -172,7 +217,8 @@ class AccessApprovalAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([parent]):
+        has_flattened_params = any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -197,7 +243,7 @@ class AccessApprovalAsyncClient:
                 predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
             ),
             default_timeout=600.0,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Certain fields should be provided within the metadata header;
@@ -255,7 +301,8 @@ class AccessApprovalAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -280,7 +327,7 @@ class AccessApprovalAsyncClient:
                 predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
             ),
             default_timeout=600.0,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Certain fields should be provided within the metadata header;
@@ -335,7 +382,7 @@ class AccessApprovalAsyncClient:
         rpc = gapic_v1.method_async.wrap_method(
             self._client._transport.approve_approval_request,
             default_timeout=600.0,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Certain fields should be provided within the metadata header;
@@ -395,7 +442,7 @@ class AccessApprovalAsyncClient:
         rpc = gapic_v1.method_async.wrap_method(
             self._client._transport.dismiss_approval_request,
             default_timeout=600.0,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Certain fields should be provided within the metadata header;
@@ -449,7 +496,8 @@ class AccessApprovalAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -474,7 +522,7 @@ class AccessApprovalAsyncClient:
                 predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
             ),
             default_timeout=600.0,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Certain fields should be provided within the metadata header;
@@ -544,7 +592,8 @@ class AccessApprovalAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([settings, update_mask]):
+        has_flattened_params = any([settings, update_mask])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -565,7 +614,7 @@ class AccessApprovalAsyncClient:
         rpc = gapic_v1.method_async.wrap_method(
             self._client._transport.update_access_approval_settings,
             default_timeout=600.0,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Certain fields should be provided within the metadata header;
@@ -620,7 +669,8 @@ class AccessApprovalAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([name]):
+        has_flattened_params = any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -639,7 +689,7 @@ class AccessApprovalAsyncClient:
         rpc = gapic_v1.method_async.wrap_method(
             self._client._transport.delete_access_approval_settings,
             default_timeout=600.0,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Certain fields should be provided within the metadata header;
@@ -655,13 +705,13 @@ class AccessApprovalAsyncClient:
 
 
 try:
-    _client_info = gapic_v1.client_info.ClientInfo(
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
             "google-cloud-access-approval",
         ).version,
     )
 except pkg_resources.DistributionNotFound:
-    _client_info = gapic_v1.client_info.ClientInfo()
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
 
 __all__ = ("AccessApprovalAsyncClient",)
