@@ -19,7 +19,7 @@ import abc
 import typing
 import pkg_resources
 
-from google import auth
+from google import auth  # type: ignore
 from google.api_core import exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
@@ -30,13 +30,13 @@ from google.protobuf import empty_pb2 as empty  # type: ignore
 
 
 try:
-    _client_info = gapic_v1.client_info.ClientInfo(
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
             "google-cloud-access-approval",
         ).version,
     )
 except pkg_resources.DistributionNotFound:
-    _client_info = gapic_v1.client_info.ClientInfo()
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
 
 class AccessApprovalTransport(abc.ABC):
@@ -52,6 +52,7 @@ class AccessApprovalTransport(abc.ABC):
         credentials_file: typing.Optional[str] = None,
         scopes: typing.Optional[typing.Sequence[str]] = AUTH_SCOPES,
         quota_project_id: typing.Optional[str] = None,
+        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
@@ -69,6 +70,11 @@ class AccessApprovalTransport(abc.ABC):
             scope (Optional[Sequence[str]]): A list of scopes.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
+                The client info used to send a user-agent string along with	
+                API requests. If ``None``, then default info will be used.	
+                Generally, you only need to set this if you're developing	
+                your own client library.
         """
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
@@ -96,9 +102,9 @@ class AccessApprovalTransport(abc.ABC):
         self._credentials = credentials
 
         # Lifted into its own function so it can be stubbed out during tests.
-        self._prep_wrapped_messages()
+        self._prep_wrapped_messages(client_info)
 
-    def _prep_wrapped_messages(self):
+    def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.list_approval_requests: gapic_v1.method.wrap_method(
@@ -110,7 +116,7 @@ class AccessApprovalTransport(abc.ABC):
                     predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
                 ),
                 default_timeout=600.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
             self.get_approval_request: gapic_v1.method.wrap_method(
                 self.get_approval_request,
@@ -121,17 +127,17 @@ class AccessApprovalTransport(abc.ABC):
                     predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
                 ),
                 default_timeout=600.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
             self.approve_approval_request: gapic_v1.method.wrap_method(
                 self.approve_approval_request,
                 default_timeout=600.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
             self.dismiss_approval_request: gapic_v1.method.wrap_method(
                 self.dismiss_approval_request,
                 default_timeout=600.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
             self.get_access_approval_settings: gapic_v1.method.wrap_method(
                 self.get_access_approval_settings,
@@ -142,17 +148,17 @@ class AccessApprovalTransport(abc.ABC):
                     predicate=retries.if_exception_type(exceptions.ServiceUnavailable,),
                 ),
                 default_timeout=600.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
             self.update_access_approval_settings: gapic_v1.method.wrap_method(
                 self.update_access_approval_settings,
                 default_timeout=600.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
             self.delete_access_approval_settings: gapic_v1.method.wrap_method(
                 self.delete_access_approval_settings,
                 default_timeout=600.0,
-                client_info=_client_info,
+                client_info=client_info,
             ),
         }
 
